@@ -4,9 +4,8 @@ from django.views.decorators.csrf import csrf_exempt
 from django.core.urlresolvers import reverse
 from django.template import RequestContext
 from django.shortcuts import render_to_response
-from vkontakte_groups_statistic.models import GroupStat, GroupStatPercentage, VkontakteDeniedAccessError
-from models import Group
-from forms import GroupImportStatisticForm, GroupImportPostsForm
+from models import VkontakteDeniedAccessError, Group, parse_statistic_for_group
+from forms import GroupImportStatisticForm
 import re
 import logging
 
@@ -39,7 +38,7 @@ def import_statistic(request, redirect_url_name=None, form_class=GroupImportStat
     return render_to_response('vkontakte_groups_statistic/import_group_statistic.html', context, context_instance=RequestContext(request))
 
 @csrf_exempt
-def import_statistic_via_bookmarklet(request, redirect_url_name=None):
+def import_statistic_via_bookmarklet(request, redirect_url_name=None, redirect_kwargs=None):
     # TODO: show errors instead of redirect
     try:
         url, content = request.POST['url'], request.POST['body']
@@ -56,9 +55,13 @@ def import_statistic_via_bookmarklet(request, redirect_url_name=None):
     act, group_id = m[0]
     group = Group.remote.fetch(ids=[group_id])[0]
 
-    GroupStat.objects.parse_statistic_page(group, act, content)
-    GroupStatPercentage.objects.parse_statistic_page(group, act, content)
+    parse_statistic_for_group(group, act, content)
+
+    if redirect_kwargs is None:
+        redirect_kwargs = {}
+    redirect_kwargs['object_id'] = group.id
+
     try:
-        return HttpResponseRedirect(reverse(redirect_url_name, args=(group.id,)))
+        return HttpResponseRedirect(reverse(redirect_url_name, kwargs=redirect_kwargs))
     except:
         return HttpResponseRedirect('/')
\ No newline at end of file
